======================
Using Lcapy with LaTeX
======================

Lcapy can generate `.pgf` image files for both schematics and plots.
This format has the advantages of vector graphics and the same fonts
as the LaTeX document.

Lcapy can also generate expressions using LaTeX math markup.  These
can be automatically embedded using the `sympytex` LaTeX package (see
http://elec.otago.ac.nz/w/index.php/SympyTeX).

Here's a bare bones example that includes a figure generated by
`schtex` (see :ref:`schtex`) and equations generated with `sympytex`:

.. literalinclude:: examples/latex/demo1.tex
                    

                    
